==> kadaster-gds2-1.3-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandophalenresultaat/bestand/v20130701/Bestand.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandophalenresultaat.bestand.v20130701;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for Bestand complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="Bestand">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="bestandsnaam">
 *           &lt;simpleType>
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *               &lt;minLength value="1"/>
 *               &lt;maxLength value="256"/>
 *             &lt;/restriction>
 *           &lt;/simpleType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "Bestand", propOrder = {
    "bestandsnaam"
})
public class Bestand {

    @XmlElement(required = true)
    protected String bestandsnaam;

    /**
     * Gets the value of the bestandsnaam property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBestandsnaam() {
        return bestandsnaam;
    }

    /**
     * Sets the value of the bestandsnaam property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBestandsnaam(String value) {
        this.bestandsnaam = value;
    }

}

==> kadaster-gds2-2.1-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandophalenresultaat/bestand/v20130701/Bestand.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandophalenresultaat.bestand.v20130701;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for Bestand complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="Bestand"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="bestandsnaam"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;minLength value="1"/&gt;
 *               &lt;maxLength value="256"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "Bestand", propOrder = {
    "bestandsnaam"
})
public class Bestand {

    @XmlElement(required = true)
    protected String bestandsnaam;

    /**
     * Gets the value of the bestandsnaam property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBestandsnaam() {
        return bestandsnaam;
    }

    /**
     * Sets the value of the bestandsnaam property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBestandsnaam(String value) {
        this.bestandsnaam = value;
    }

}
